antares.apps.subscription.migrations package
============================================

Submodules
----------

antares.apps.subscription.migrations.0001\_initial module
---------------------------------------------------------

.. automodule:: antares.apps.subscription.migrations.0001_initial
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: antares.apps.subscription.migrations
   :members:
   :undoc-members:
   :show-inheritance:
